Crate next

Crate next 

next is a crate that provides a trait that gets the next value. That value is the next in the sequence implied by PartialOrd.

Traits

Next
Allows getting the next sequential value

Derive Macros

Next
Allows getting the next sequential value