pub fn vcgezd_s64(a: i64) -> u64Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Compare signed greater than or equal to zero Arm’s documentation
pub fn vcgezd_s64(a: i64) -> u64neon only.Compare signed greater than or equal to zero Arm’s documentation