vclez_f16

Function vclez_f16 

1.94.0 · Source
pub fn vclez_f16(a: float16x4_t) -> uint16x4_t
Available on (AArch64 or ARM64EC) and non-ARM64EC and target feature neon and target feature fp16 only.
Floating-point compare less than or equal to zero Arm’s documentation