pub fn vclezd_f64(a: f64) -> u64Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point compare less than or equal to zero Arm’s documentation
pub fn vclezd_f64(a: f64) -> u64neon only.Floating-point compare less than or equal to zero Arm’s documentation