pub fn vcombine_p16(a: poly16x4_t, b: poly16x4_t) -> poly16x8_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Join two smaller vectors into a single larger vector Arm’s documentation
pub fn vcombine_p16(a: poly16x4_t, b: poly16x4_t) -> poly16x8_tneon only.Join two smaller vectors into a single larger vector Arm’s documentation