pub fn vcombine_p64(a: poly64x1_t, b: poly64x1_t) -> poly64x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Join two smaller vectors into a single larger vector Arm’s documentation
pub fn vcombine_p64(a: poly64x1_t, b: poly64x1_t) -> poly64x2_tneon only.Join two smaller vectors into a single larger vector Arm’s documentation