vcvtah_s32_f16

Function vcvtah_s32_f16 

pub fn vcvtah_s32_f16(a: f16) -> i32
🔬This is a nightly-only experimental API. (stdarch_neon_f16 #136306)
Available on (AArch64 or ARM64EC) and non-ARM64EC and target feature neon and target feature fp16 only.
Floating-point convert to integer, rounding to nearest with ties to away Arm’s documentation