pub fn vcvtaq_s32_f32(a: float32x4_t) -> int32x4_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to signed integer, rounding to nearest with ties to away Arm’s documentation
pub fn vcvtaq_s32_f32(a: float32x4_t) -> int32x4_tneon only.Floating-point convert to signed integer, rounding to nearest with ties to away Arm’s documentation