pub fn vcvtn_s64_f64(a: float64x1_t) -> int64x1_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to signed integer, rounding to nearest with ties to even Arm’s documentation
pub fn vcvtn_s64_f64(a: float64x1_t) -> int64x1_tneon only.Floating-point convert to signed integer, rounding to nearest with ties to even Arm’s documentation