pub fn vcvtns_u32_f32(a: f32) -> u32Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to unsigned integer, rounding to nearest with ties to even Arm’s documentation
pub fn vcvtns_u32_f32(a: f32) -> u32neon only.Floating-point convert to unsigned integer, rounding to nearest with ties to even Arm’s documentation