pub fn vcvtp_u32_f32(a: float32x2_t) -> uint32x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to unsigned integer, rounding toward plus infinity Arm’s documentation
pub fn vcvtp_u32_f32(a: float32x2_t) -> uint32x2_tneon only.Floating-point convert to unsigned integer, rounding toward plus infinity Arm’s documentation