pub fn vcvtp_u64_f64(a: float64x1_t) -> uint64x1_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to unsigned integer, rounding toward plus infinity Arm’s documentation
pub fn vcvtp_u64_f64(a: float64x1_t) -> uint64x1_tneon only.Floating-point convert to unsigned integer, rounding toward plus infinity Arm’s documentation