pub fn vcvtpq_u32_f32(a: float32x4_t) -> uint32x4_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to unsigned integer, rounding toward plus infinity Arm’s documentation
pub fn vcvtpq_u32_f32(a: float32x4_t) -> uint32x4_tneon only.Floating-point convert to unsigned integer, rounding toward plus infinity Arm’s documentation