pub fn vcvtps_s32_f32(a: f32) -> i32Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to signed integer, rounding toward plus infinity Arm’s documentation
pub fn vcvtps_s32_f32(a: f32) -> i32neon only.Floating-point convert to signed integer, rounding toward plus infinity Arm’s documentation