pub fn vcvtx_f32_f64(a: float64x2_t) -> float32x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to lower precision narrow, rounding to odd Arm’s documentation
pub fn vcvtx_f32_f64(a: float64x2_t) -> float32x2_tneon only.Floating-point convert to lower precision narrow, rounding to odd Arm’s documentation