pub fn vdupb_lane_p8(a: poly8x8_t, const N: i32) -> u8Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdupb_lane_p8(a: poly8x8_t, const N: i32) -> u8neon only.Set all vector lanes to the same value Arm’s documentation