pub fn vdupd_lane_f64(a: float64x1_t, const N: i32) -> f64Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdupd_lane_f64(a: float64x1_t, const N: i32) -> f64neon only.Set all vector lanes to the same value Arm’s documentation