pub fn vdupd_lane_u64(a: uint64x1_t, const N: i32) -> u64Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdupd_lane_u64(a: uint64x1_t, const N: i32) -> u64neon only.Set all vector lanes to the same value Arm’s documentation