pub fn vduph_lane_p16(a: poly16x4_t, const N: i32) -> u16Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vduph_lane_p16(a: poly16x4_t, const N: i32) -> u16neon only.Set all vector lanes to the same value Arm’s documentation