pub fn vduph_lane_s16(a: int16x4_t, const N: i32) -> i16Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vduph_lane_s16(a: int16x4_t, const N: i32) -> i16neon only.Set all vector lanes to the same value Arm’s documentation