pub fn vdups_lane_u32(a: uint32x2_t, const N: i32) -> u32Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdups_lane_u32(a: uint32x2_t, const N: i32) -> u32neon only.Set all vector lanes to the same value Arm’s documentation