pub fn vqrdmulhq_s32(a: int32x4_t, b: int32x4_t) -> int32x4_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Signed saturating rounding doubling multiply returning high half Arm’s documentation
pub fn vqrdmulhq_s32(a: int32x4_t, b: int32x4_t) -> int32x4_tneon only.Signed saturating rounding doubling multiply returning high half Arm’s documentation