pub fn vrnda_f64(a: float64x1_t) -> float64x1_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point round to integral, to nearest with ties to away Arm’s documentation
pub fn vrnda_f64(a: float64x1_t) -> float64x1_tneon only.Floating-point round to integral, to nearest with ties to away Arm’s documentation