pub fn vrndaq_f32(a: float32x4_t) -> float32x4_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point round to integral, to nearest with ties to away Arm’s documentation
pub fn vrndaq_f32(a: float32x4_t) -> float32x4_tneon only.Floating-point round to integral, to nearest with ties to away Arm’s documentation