pub fn vrndiq_f32(a: float32x4_t) -> float32x4_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point round to integral, using current rounding mode Arm’s documentation
pub fn vrndiq_f32(a: float32x4_t) -> float32x4_tneon only.Floating-point round to integral, using current rounding mode Arm’s documentation