pub fn vrndiq_f64(a: float64x2_t) -> float64x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point round to integral, using current rounding mode Arm’s documentation
pub fn vrndiq_f64(a: float64x2_t) -> float64x2_tneon only.Floating-point round to integral, using current rounding mode Arm’s documentation