pub fn vrndn_f32(a: float32x2_t) -> float32x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point round to integral, to nearest with ties to even Arm’s documentation
pub fn vrndn_f32(a: float32x2_t) -> float32x2_tneon only.Floating-point round to integral, to nearest with ties to even Arm’s documentation