pub fn vrndns_f32(a: f32) -> f32Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point round to integral, to nearest with ties to even Arm’s documentation
pub fn vrndns_f32(a: f32) -> f32neon only.Floating-point round to integral, to nearest with ties to even Arm’s documentation