vrndx_f16

Function vrndx_f16 

1.94.0 · Source
pub fn vrndx_f16(a: float16x4_t) -> float16x4_t
Available on (AArch64 or ARM64EC) and non-ARM64EC and target feature neon and target feature fp16 only.
Floating-point round to integral exact, using current rounding mode Arm’s documentation