_m_prefetchrs

Function _m_prefetchrs 

pub fn _m_prefetchrs(p: *const u8)
🔬This is a nightly-only experimental API. (movrs_target_feature #137976)
Available on x86 and target feature movrs only.
Prefetches the cache line that contains address p, with an indication that the source memory location is likely to become read-shared by multiple processors, i.e., read in the future by at least one other processor before it is written, assuming it is ever written in the future.

Note: this intrinsic is safe to use even though it takes a raw pointer argument. In general, this cannot change the behavior of the program, including not trapping on invalid pointers.