pub unsafe fn __tile_stream_loaddrs(
dst: *mut __tile1024i,
base: *const u8,
stride: usize,
)🔬This is a nightly-only experimental API. (
x86_amx_intrinsics #126622)Available on x86-64 and target feature
amx-movrs only.Expand description
Load tile rows from memory specified by base address and stride into destination tile dst.
The shape of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.
Provides a hint to the implementation that the data would be reused but does not need
to be resident in the nearest cache levels.
Additionally, this intrinsic indicates the source memory location is likely to become
read-shared by multiple processors, i.e., read in the future by at least one other processor
before it is written, assuming it is ever written in the future.