pub unsafe fn _mm256_2intersect_epi32(
a: __m256i,
b: __m256i,
k1: *mut __mmask8,
k2: *mut __mmask8,
)🔬This is a nightly-only experimental API. (
stdarch_x86_avx512vp2intersect #111137)Available on x86-64 and (x86 or x86-64) and target feature
avx512vp2intersect and target feature avx512vl only.Expand description
Compute intersection of packed 32-bit integer vectors a and b, and store indication of match in the corresponding bit of two mask registers specified by k1 and k2. A match in corresponding elements of a and b is indicated by a set bit in the corresponding bit of the mask registers.