_mm256_zeroall

Function _mm256_zeroall 

1.27.0 · Source
pub fn _mm256_zeroall()
Available on x86-64 and (x86 or x86-64) and target feature avx only.
Zeroes the contents of all XMM or YMM registers.

This operation is purely a performance hint for the CPU and has no effect on the Abstract Machine state.

Intel’s documentation