pub unsafe fn _tile_storeconfig(mem_addr: *mut u8)🔬This is a nightly-only experimental API. (
x86_amx_intrinsics #126622)Available on x86-64 and target feature
amx-tile only.Expand description
Stores the current tile configuration to a 64-byte memory location specified by mem_addr.
The tile configuration format is as specified in _tile_loadconfig, and includes the tile type pallette,
the number of bytes per row, and the number of rows. If tiles are not configured, all zeroes will be stored to memory.