atomic_min

Function atomic_min 

pub const unsafe fn atomic_min<T: Copy, const ORD: AtomicOrdering>(
    dst: *mut T,
    src: T,
) -> T
🔬This is a nightly-only experimental API. (core_intrinsics)
Minimum with the current value using a signed comparison. T must be a signed integer type.

Safety

This is equivalent to Atomic<T>::from_ptr followed by Atomic<T>::fetch_min. Refer to the documentation of Atomic<T>::from_ptr for safety requirements.

The stabilized version of this intrinsic is available on the atomic signed integer types via the fetch_min method. For example, AtomicI32::fetch_min.