pub struct Attribute<const ID: u64, O, Data> { /* private fields */ }Expand description
A configfs attribute.
An attribute appears as a file in configfs, inside a folder that represent the group that the attribute belongs to.
Implementations