pub struct CoreInternal<'a>(/* private fields */);Expand description
Semantically the same as Core, but reserved for internal usage of the corresponding bus
abstraction.
The internal core context is intended to be used in exactly the same way as the Core
context, with the difference that this DeviceContext is internal to the corresponding bus
abstraction.
This context mainly exists to share generic Device infrastructure that should only be called
from bus callbacks with bus abstractions, but without making them accessible for drivers.