pub struct IdArray<T: RawDeviceId, U: 'static, const N: usize> { /* private fields */ }Expand description
A zero-terminated device id array, followed by context data.
Implementations
Sourceimpl<T: RawDeviceId + RawDeviceIdIndex, U: 'static, const N: usize> IdArray<T, U, N>
impl<T: RawDeviceId + RawDeviceIdIndex, U: 'static, const N: usize> IdArray<T, U, N>
Sourcepub const fn new(ids: [(T, &'static U); N]) -> Self
pub const fn new(ids: [(T, &'static U); N]) -> Self
Creates a new instance of the array.
The contents are derived from the given identifiers and context information.
Sourceimpl<T: RawDeviceId, const N: usize> IdArray<T, (), N>
impl<T: RawDeviceId, const N: usize> IdArray<T, (), N>
Sourcepub const fn new_without_index(ids: [T; N]) -> Self
pub const fn new_without_index(ids: [T; N]) -> Self
Creates a new instance of the array without writing index values.
The contents are derived from the given identifiers and context information.
If the device implements RawDeviceIdIndex, consider using IdArray::new instead.