pub struct UnregisteredDevice<T: Driver>(/* private fields */);Expand description
A Device which is known at compile-time to be unregistered with userspace.
This type allows performing operations which are only safe to do before userspace registration,
and can be used to create a Registration once the driver is ready
to register the device with userspace.
Since DRM device initialization must be single-threaded, this object is not thread-safe.
Invariants
The device in self.0 is guaranteed to be a newly created Device that has not yet been
registered with userspace until this type is dropped.
Implementations