pub struct Object<T: DriverObject> { /* private fields */ }Expand description
A shmem-backed GEM object.
Invariants
objcontains a valid initializedstruct drm_gem_shmem_objectfor the lifetime of this object.
Implementations
Sourceimpl<T: DriverObject> Object<T>
impl<T: DriverObject> Object<T>
Sourceimpl<T: DriverObject> Object<T>
impl<T: DriverObject> Object<T>
Sourcepub fn vmap<const SIZE: usize>(&self) -> Result<VMapRef<'_, T, SIZE>>
pub fn vmap<const SIZE: usize>(&self) -> Result<VMapRef<'_, T, SIZE>>
Creates and returns a virtual kernel memory mapping for this object.
Sourcepub fn sg_table<'a>(&'a self, dev: &'a Device<Bound>) -> Result<&'a SGTable>
pub fn sg_table<'a>(&'a self, dev: &'a Device<Bound>) -> Result<&'a SGTable>
Creates (if necessary) and returns an immutable reference to a scatter-gather table of DMA pages for this object.
This will pin the object in memory. It is expected that dev should be a pointer to the
same device::Device which self belongs to, otherwise this function will return
Err(EINVAL).
Sourcepub fn new(
dev: &Device<T::Driver>,
size: usize,
config: ObjectConfig<'_, T>,
args: T::Args,
) -> Result<ARef<Self>>
pub fn new( dev: &Device<T::Driver>, size: usize, config: ObjectConfig<'_, T>, args: T::Args, ) -> Result<ARef<Self>>
Create a new shmem-backed DRM object of the given size.
Additional config options can be specified using config.
Sourcepub fn owned_vmap<const SIZE: usize>(&self) -> Result<VMapOwned<T, SIZE>>
pub fn owned_vmap<const SIZE: usize>(&self) -> Result<VMapOwned<T, SIZE>>
Creates and returns an owned reference to a virtual kernel memory mapping for this object.