pub struct SGTableMap<T: DriverObject> { /* private fields */ }Expand description
A reference to a GEM object that is known to have a mapped SGTable.
This is used by the Rust bindings with Devres in order to ensure that mappings for SGTables
on GEM shmem objects are revoked on driver-unbind.
Invariants
self.objalways points to a valid GEM object.- This object is proof that
self.obj.owner.sgt_reshas an initialized and valid pointer to anSGTable.
Methods from Deref<Target = SGTable>
Sourcepub fn project<'__pin>(
self: Pin<&'__pin mut Self>,
) -> SGTableProjection<'__pin, T>
pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> SGTableProjection<'__pin, T>
Pin-projects all fields of Self.
These fields are structurally pinned:
inner
These fields are not structurally pinned:
Sourcepub fn iter(&self) -> SGTableIter<'_> ⓘ
pub fn iter(&self) -> SGTableIter<'_> ⓘ
Returns an SGTableIter bound to the lifetime of self.