Error

Struct Error 

pub struct Error(/* private fields */);
Generic integer kernel error.

The kernel defines a set of integer generic error codes based on C and POSIX ones. These codes may have a more specific meaning in some contexts.

Invariants

The value is a valid errno (i.e. >= -MAX_ERRNO && < 0).

Implementations

Source

impl Error

pub fn from_errno(errno: c_int) -> Error

Creates an Error from a kernel error code.

errno must be within error code range (i.e. >= -MAX_ERRNO && < 0).

It is a bug to pass an out-of-range errno. code::EINVAL is returned in such a case.

Examples
assert_eq!(Error::from_errno(-1), EPERM);
assert_eq!(Error::from_errno(-2), ENOENT);

The following calls are considered a bug:

assert_eq!(Error::from_errno(0), EINVAL);
assert_eq!(Error::from_errno(-1000000), EINVAL);
pub fn to_errno(self) -> c_int

Returns the kernel error code.

pub fn to_ptr<T>(self) -> *mut T

Returns the error encoded as a pointer.

pub fn name(&self) -> Option<&'static CStr>

Returns a string representing the error, if one exists.