pub struct Device<Ctx: DeviceContext = Normal>(/* private fields */);Expand description
A faux device.
A faux device is a virtual device backed by the faux bus, primarily used for scenarios where a real hardware device is not available or for testing.
Invariants
The underlying struct faux_device is valid.