pub struct Registration(/* private fields */);Expand description
The registration of a faux device.
This type represents the registration of a struct faux_device. When an instance of this type
is dropped, its respective faux device will be unregistered from the system.
Invariants
self.0always holds a valid pointer to an initialized and registeredstruct faux_device.- This object is proof that the object described by this
Registrationis bound to a device.
Implementations