pub struct HashedPtr<T: ?Sized>(pub *const T);Expand description
A wrapper for pointers that formats them using kernel’s %p format specifier.
By default, %p prints a hashed representation of the pointer address to prevent kernel address
leaks. When the no_hash_pointers kernel command-line parameter is enabled, the real address is
printed instead (for debugging purposes).
Tuple Fields
0: *const TTrait Implementations