pub enum FwRpcResponse {
InPlace(usize),
NewBuffer(KVVec<u8>),
}Expand description
Response from a Operations::fw_rpc call.
Variants
InPlace(usize)
Reuse the input buffer as the output, with the given output length.
The callback returns EINVAL if the output length exceeds the input buffer length.
NewBuffer(KVVec<u8>)
Return a newly allocated buffer as the output.