AllocatedBlock

Struct AllocatedBlock 

pub struct AllocatedBlock<'a> { /* private fields */ }
A buddy block paired with its owning AllocatedBlocks context.

Unlike a raw block, which only knows its offset within the buddy address space, an AllocatedBlock also has access to the allocator’s base_offset and chunk_size, enabling it to compute absolute offsets and byte sizes.

Returned by AllocatedBlocks::iter().

Implementations

Source

impl AllocatedBlock<'_>

pub fn offset(&self) -> u64

Get the block’s offset in the address space.

Returns the absolute offset including the allocator’s base offset. This is the actual address to use for accessing the allocated memory.

pub fn order(&self) -> u32

Get the block order (size = chunk_size << order).

pub fn size(&self) -> u64

Get the block’s size in bytes.