AllocatedBlocks

Struct AllocatedBlocks 

pub struct AllocatedBlocks { /* private fields */ }
Allocated blocks from the buddy allocator with automatic cleanup.

This structure owns a list of allocated blocks and ensures they are automatically freed when dropped. Use iter() to iterate over all allocated blocks.

Invariants

  • list is an initialized, valid list head containing allocated blocks.

Implementations

Source

impl AllocatedBlocks

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> AllocatedBlocksProjection<'__pin>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • list

These fields are not structurally pinned:

  • buddy
Source

impl AllocatedBlocks

pub fn is_empty(&self) -> bool

Check if the block list is empty.

pub fn iter(&self) -> impl Iterator<Item = AllocatedBlock<'_>> + '_

Iterate over allocated blocks.

Returns an iterator yielding AllocatedBlock values. Each AllocatedBlock borrows self and is only valid for the duration of that borrow.