pub struct I2cAdapter<Ctx: DeviceContext = Normal>(/* private fields */);Expand description
The i2c adapter representation.
This structure represents the Rust abstraction for a C struct i2c_adapter. The
implementation abstracts the usage of an existing C struct i2c_adapter that
gets passed from the C side
Invariants
A I2cAdapter instance represents a valid struct i2c_adapter created by the C portion of
the kernel.
Implementations