pub struct Registration(/* private fields */);Expand description
The registration of an i2c client device.
This type represents the registration of a [struct i2c_client]. When an instance of this
type is dropped, its respective i2c client device will be unregistered from the system.
Invariants
self.0 always holds a valid pointer to an initialized and registered
[struct i2c_client].
Implementations
Sourceimpl Registration
impl Registration
Sourcepub fn new<'a>(
i2c_adapter: &I2cAdapter,
i2c_board_info: &I2cBoardInfo,
parent_dev: &'a Device<Bound>,
) -> impl PinInit<Devres<Self>, Error> + 'a
pub fn new<'a>( i2c_adapter: &I2cAdapter, i2c_board_info: &I2cBoardInfo, parent_dev: &'a Device<Bound>, ) -> impl PinInit<Devres<Self>, Error> + 'a
The C i2c_new_client_device function wrapper for manual I2C client creation.