pub fn local_interrupt_disable() -> LocalInterruptDisabledExpand description
Disable local processor interrupts on a preemptible kernel.
This function disables local processor interrupts on a preemptible kernel, and returns a
LocalInterruptDisabled token as proof of this. On non-preemptible kernels, this function is
a no-op.
Usage of this function is discouraged unless you are absolutely sure you know what you are doing, as kernel interfaces for Rust that deal with interrupt state will typically handle local processor interrupt state management on their own and managing this by hand is quite error prone.