LocalInterruptDisabled

Struct LocalInterruptDisabled 

pub struct LocalInterruptDisabled(/* private fields */);
A guard that represents local processor interrupt disablement on preemptible kernels.

LocalInterruptDisabled is a guard type that represents that local processor interrupts have been disabled on a preemptible kernel.

Certain functions take an immutable reference of LocalInterruptDisabled in order to require that they may only be run in local-interrupt-disabled contexts on preemptible kernels.

This is a marker type; it has no size, and is simply used as a compile-time guarantee that local processor interrupts are disabled on preemptible kernels. Note that no guarantees about the state of interrupts are made by this type on non-preemptible kernels.

Invariants

Local processor interrupts are disabled on preemptible kernels for as long as an object of this type exists.

Implementations

Source

impl LocalInterruptDisabled

pub unsafe fn assume_disabled<'a>() -> &'a LocalInterruptDisabled

Assume that local processor interrupts are disabled on preemptible kernels.

This can be used for annotating code that is known to be run in contexts where local processor interrupts are disabled on preemptible kernels. It makes no changes to the local interrupt state on its own.

Safety

For the whole life 'a, local interrupts must be disabled on preemptible kernels. This could be a context like, for example, an interrupt handler.