ExclusiveIoMem

Struct ExclusiveIoMem 

pub struct ExclusiveIoMem<'a, const SIZE: usize> { /* private fields */ }
An exclusive memory-mapped IO region.

Invariants

Implementations

Source

impl<'a, const SIZE: usize> ExclusiveIoMem<'a, SIZE>

pub fn into_devres(self) -> Result<DevresExclusiveIoMem<SIZE>>

Consume the ExclusiveIoMem and register it as a device-managed resource.

The returned DevresExclusiveIoMem can outlive the original borrow and be stored in driver data. Access to the I/O memory is revoked automatically when the device is unbound.