IoMem

Struct IoMem 

pub struct IoMem<'a, const SIZE: usize = 0> { /* private fields */ }
A generic memory-mapped IO region.

Accesses to the underlying region is checked either at compile time, if the region’s size is known at that point, or at runtime otherwise.

Invariants

IoMem always holds an MmioRaw instance that holds a valid pointer to the start of the I/O memory mapped region.

Implementations

Source

impl<'a, const SIZE: usize> IoMem<'a, SIZE>

pub fn into_devres(self) -> Result<DevresIoMem<SIZE>>

Consume the IoMem and register it as a device-managed resource.

The returned DevresIoMem can outlive the original borrow and be stored in driver data. Access to the I/O memory is revoked automatically when the device is unbound.