RelativeRegisterArrayLoc

Struct RelativeRegisterArrayLoc 

pub struct RelativeRegisterArrayLoc<T: RelativeRegisterArray, B: RegisterBase<T::BaseFamily> + ?Sized>(/* private fields */);
Location of a relative array register.

Implementations

Source

impl<T, B> RelativeRegisterArrayLoc<T, B>

pub fn new(idx: usize) -> Self

Returns the location of register T from the base B at index idx, with build-time validation.

pub fn try_new(idx: usize) -> Option<Self>

Attempts to return the location of register T from the base B at index idx, with runtime validation.