Array

Trait Array 

pub trait Array {
    // Provided methods
    fn at(idx: usize) -> RegisterArrayLoc<Self>
       where Self: RegisterArray { ... }
    fn try_at(idx: usize) -> Option<RegisterArrayLoc<Self>>
       where Self: RegisterArray { ... }
}
Trait providing location builders for RegisterArrays.

Provided Methods

fn at(idx: usize) -> RegisterArrayLoc<Self>
where Self: RegisterArray,

Returns the location of the register at position idx, with build-time validation.

fn try_at(idx: usize) -> Option<RegisterArrayLoc<Self>>
where Self: RegisterArray,

Returns the location of the register at position idx, with runtime validation.

Implementors