LocatedRegister

Trait LocatedRegister 

pub trait LocatedRegister {
    type Value: Register;
    type Location: IoLoc<Self::Value>;

    // Required method
    fn into_io_op(self) -> (Self::Location, Self::Value);
}
Trait implemented by items that contain both a register value and the absolute I/O location at which to write it.

Implementors can be used with Io::write_reg.

Required Associated Types

type Value: Register

Register value to write.

type Location: IoLoc<Self::Value>

Full location information at which to write the value.

Required Methods

fn into_io_op(self) -> (Self::Location, Self::Value)

Consumes self and returns a (location, value) tuple describing a valid I/O write operation.

Implementors