pub struct Mmio<'a, T: ?Sized> { /* private fields */ }Expand description
A view of memory-mapped I/O region.
Invariant
ptr points to a valid and aligned memory-mapped I/O region for the duration lifetime 'a.
Implementations
Sourceimpl<'a, T: ?Sized> Mmio<'a, T>
impl<'a, T: ?Sized> Mmio<'a, T>
Sourcepub fn relaxed(self) -> RelaxedMmio<'a, T>
pub fn relaxed(self) -> RelaxedMmio<'a, T>
Returns a RelaxedMmio that performs relaxed I/O operations.
Relaxed accessors do not provide ordering guarantees with respect to DMA or memory accesses and can be used when such ordering is not required.
Examples
use kernel::io::{
Io,
Mmio,
Region,
RelaxedMmio,
};
fn do_io(io: Mmio<'_, Region<0x100>>) {
// The access is performed using `readl_relaxed` instead of `readl`.
let v = io.relaxed().read32(0x10);
}