MmioRaw

Struct MmioRaw 

pub struct MmioRaw<T: ?Sized> { /* private fields */ }
Raw representation of an MMIO region.

MmioRaw<T> is equivalent to T __iomem * in C.

By itself, the existence of an instance of this structure does not provide any guarantees that the represented MMIO region does exist or is properly mapped.

Instead, the bus specific MMIO implementation must convert this raw representation into an Mmio instance providing the actual memory accessors. Only by the conversion into an Mmio structure any guarantees are given.

Implementations

Source

impl<T> MmioRaw<T>

pub fn new(addr: usize) -> Self

Create a MmioRaw from address.

Source

impl<const SIZE: usize> MmioRaw<Region<SIZE>>

pub fn new_region(addr: usize, size: usize) -> Result<Self>

Create a MmioRaw representing a I/O region with given size.

The size is checked against the minimum size specified via const generics.

Source

impl<T: ?Sized + KnownSize> MmioRaw<T>

pub fn addr(&self) -> usize

Returns the base address of the MMIO region.

pub fn size(&self) -> usize

Returns the size of the MMIO region.