pub trait IoBase<'a>: Copy {
type Backend: IoBackend;
type Target: ?Sized + KnownSize;
// Required method
fn as_view(self) -> <Self::Backend as IoBackend>::View<'a, Self::Target>;
}Expand description
Types implementing this trait (e.g. MMIO BARs or PCI config regions) can perform I/O operations on regions of memory.
This trait defines which backend shall be used for I/O operations and provides a method to
convert into IoBackend::View. Users should use the Io trait which provides the actual
methods to perform I/O operations.
This should be implemented on cheaply copyable handles, such as references or view types.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".