pub struct ListLinks<const ID: u64 = 0> { /* private fields */ }Expand description
The prev/next pointers for an item in a linked list.
Invariants
The fields are null if and only if this item is not in a list.
Implementations