macro_rules! new_spinlock_irq {
($inner:expr $(, $name:literal)? $(,)?) => { ... };
}Expand description
Creates a SpinLockIrq initialiser with the given name and a newly-created lock class.
It uses the name if one is given, otherwise it generates one based on the file name and line number.