pub struct ModuleParamAccess<T> { /* private fields */ }Expand description
A wrapper for kernel parameters.
This type is instantiated by the module! macro when module parameters are
defined. You should never need to instantiate this type directly.
Note: This type is pub because it is used by module crates to access
parameter values.
Implementations
Sourceimpl<T> ModuleParamAccess<T>
impl<T> ModuleParamAccess<T>
Sourcepub fn value(&self) -> Twhere
T: Copy,
pub fn value(&self) -> Twhere
T: Copy,
Get a copy of the parameter value.
Returns the value supplied at module load time, or the default value if the parameter has not been set.
Sourcepub fn value_ref(&self) -> &T
pub fn value_ref(&self) -> &T
Get a shared reference to the parameter value.
Returns a reference to the value supplied at module load time, or a reference to the default value if the parameter has not been set.
Sourcepub const fn as_void_ptr(&self) -> *mut c_void
pub const fn as_void_ptr(&self) -> *mut c_void
Get a mutable pointer to self.
NOTE: In most cases it is not safe deref the returned pointer.