Family

Struct Family 

pub struct Family { /* private fields */ }
A generic netlink family.

Implementations

Source

impl Family

pub const fn const_new( module: &ThisModule, name: &[u8], version: u32, mcgrps: &'static [MulticastGroup], ) -> Family

Creates a new Family instance.

Intended to be used from const context only. Will panic if provided with invalid arguments.

The name must be a nul-terminated string, but it is taken as &[u8] so that it can be used more conveniently with the strings generated by bindgen.

pub fn has_listeners(&self, group: u32) -> bool

Checks if there are any listeners for the given multicast group.

pub fn as_raw(&self) -> *mut genl_family

Returns a raw pointer to the underlying genl_family structure.

Source

impl Family

pub fn register(&'static self) -> Result<Registration>

Registers the generic netlink family with the kernel.