pub struct NetlinkSkBuff { /* private fields */ }Expand description
A wrapper around struct sk_buff for generic netlink messages.
This type is intended to be specific for buffers used with netlink only, and other usecases for
struct sk_buff are out-of-scope for this abstraction.
Invariants
The pointer has ownership over a valid sk_buff.
Implementations
Sourceimpl NetlinkSkBuff
impl NetlinkSkBuff
Sourcepub fn new(size: usize, flags: Flags) -> Result<NetlinkSkBuff, AllocError>
pub fn new(size: usize, flags: Flags) -> Result<NetlinkSkBuff, AllocError>
Creates a new NetlinkSkBuff with the given size.
Sourcepub fn genlmsg_put(
self,
portid: u32,
seq: u32,
family: &'static Family,
cmd: u8,
) -> Result<GenlMsg, AllocError>
pub fn genlmsg_put( self, portid: u32, seq: u32, family: &'static Family, cmd: u8, ) -> Result<GenlMsg, AllocError>
Puts a generic netlink header into the NetlinkSkBuff.