u64_into_u16

Function u64_into_u16 

pub const fn u64_into_u16<const N: u64>() -> u16
Performs a build-time safe conversion of a u64 constant value into a u16.

This checks at compile-time that the conversion is lossless, and triggers a build error if it isn’t.

Examples

use kernel::num::casts;

// Succeeds because the value of the source fits into the destination's type.
assert_eq!(casts::u64_into_u16::<1u64>(), 1u16);