usize_into_u16

Function usize_into_u16 

pub const fn usize_into_u16<const N: usize>() -> u16
Performs a build-time safe conversion of a usize constant value into a u16.

This checks at compile-time that the conversion is lossless, and triggers a build error if it isn’t.

Examples

use kernel::num::casts;

// Succeeds because the value of the source fits into the destination's type.
assert_eq!(casts::usize_into_u16::<1usize>(), 1u16);