SearchType

Enum SearchType 

pub enum SearchType {
    Exact,
    Floor,
    Ceil,
}
OPP search options.

Examples

Defines how to search for an OPP in a Table relative to a frequency.

use kernel::clk::Hertz;
use kernel::error::Result;
use kernel::opp::{OPP, SearchType, Table};
use kernel::sync::aref::ARef;

fn find_opp(table: &Table, freq: Hertz) -> Result<ARef<OPP>> {
    let opp = table.opp_from_freq(freq, Some(true), None, SearchType::Exact)?;

    pr_info!("OPP frequency is: {:?}\n", opp.freq(None));
    pr_info!("OPP voltage is: {:?}\n", opp.voltage());
    pr_info!("OPP level is: {}\n", opp.level());
    pr_info!("OPP power is: {:?}\n", opp.power());

    Ok(opp)
}

Variants



Exact

Match the exact frequency.



Floor

Find the highest frequency less than or equal to the given value.



Ceil

Find the lowest frequency greater than or equal to the given value.