pub struct Token { /* private fields */ }Expand description
Handle for a dynamically created OPP.
The associated OPP is automatically removed when the Token is dropped.
Examples
The following example demonstrates how to create an OPP dynamically.
use kernel::clk::Hertz;
use kernel::device::Device;
use kernel::error::Result;
use kernel::opp::{Data, MicroVolt, Token};
use kernel::sync::aref::ARef;
fn create_opp(dev: &ARef<Device>, freq: Hertz, volt: MicroVolt, level: u32) -> Result<Token> {
let data = Data::new(freq, volt, level, false);
// OPP is removed once token goes out of scope.
data.add_opp(dev)
}Trait Implementations