pub struct ConfigSpace<'a, S: ConfigSpaceKind = Extended> { /* private fields */ }Expand description
The PCI configuration space of a device.
Provides typed read and write accessors for configuration registers
using the standard pci_read_config_* and pci_write_config_* helpers.
The generic parameter S indicates the maximum size of the configuration space.
Use Normal for 256-byte legacy configuration space or Extended for
4096-byte PCIe extended configuration space (default).