pub enum RoundingOutcome {
ExactOrRoundedDown,
RoundedUp,
}Expand description
Describes the outcome of a round_waveform operation.
Variants
ExactOrRoundedDown
The requested waveform was achievable exactly or by rounding values down.
RoundedUp
The requested waveform could only be achieved by rounding up.