pub enum Entry<'a, K, V> {
Vacant(VacantEntry<'a, K, V>),
Occupied(OccupiedEntry<'a, K, V>),
}Expand description
A view into a single entry in a map, which may either be vacant or occupied.
This enum is constructed from the RBTree::entry.
Variants
Vacant(VacantEntry<'a, K, V>)
This RBTree does not have a node with this key.
Occupied(OccupiedEntry<'a, K, V>)
This RBTree already has a node with this key.