pub struct Disabled;Expand description
A state where this Regulator handle has not specifically asked for the
underlying regulator to be enabled. This means that this reference does not
own an enable reference count, but the regulator may still be on.