pub trait AtomicImpl:
Sized
+ Copy
+ Sealed {
type Delta;
}Expand description
A marker trait for types that implement atomic operations with C side primitives.
This trait is sealed, and only types that map directly to the C side atomics or can be implemented with lower-level C primitives are allowed to implement this:
i8,i16and*const c_voidare implemented with lower-level C primitives.i32map toatomic_ti64map toatomic64_t
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.