pub struct Lock<T: ?Sized, B: Backend> { /* private fields */ }Expand description
A mutual exclusion primitive.
Exposes one of the kernel locking primitives. Which one is exposed depends on the lock
Backend specified as the generic parameter B.
Implementations
Sourceimpl<T: ?Sized> Lock<T, SpinLockIrqBackend>
impl<T: ?Sized> Lock<T, SpinLockIrqBackend>
Sourcepub fn lock_with<'a>(
&'a self,
context: &'a LocalInterruptDisabled,
) -> SpinLockGuard<'a, T>
pub fn lock_with<'a>( &'a self, context: &'a LocalInterruptDisabled, ) -> SpinLockGuard<'a, T>
Acquires the lock without modifying local interrupt state.
This function should be used in place of the more expensive Lock::lock() function when
possible for SpinLockIrq locks.
Sourcepub fn try_lock_with<'a>(
&'a self,
context: &'a LocalInterruptDisabled,
) -> Option<SpinLockGuard<'a, T>>
pub fn try_lock_with<'a>( &'a self, context: &'a LocalInterruptDisabled, ) -> Option<SpinLockGuard<'a, T>>
Tries to acquire the lock without modifying local interrupt state.
This function should be used in place of the more expensive Lock::try_lock() function
when possible for SpinLockIrq locks.
Returns a guard that can be used to access the data protected by the lock if successful.