pub struct Guard(/* private fields */);Expand description
Evidence that the RCU read side lock is held on the current thread/CPU.
The type is explicitly not Send because this property is per-thread/CPU.
Invariants
The RCU read side lock is actually held while instances of this guard exist.
Implementations