pub fn udelay(delta: Delta)Expand description
Inserts a delay based on microseconds with busy waiting.
Equivalent to the C side udelay(), which delays in microseconds.
delta must be within [0, MAX_UDELAY_MS] in milliseconds;
otherwise, it is erroneous behavior. That is, it is considered a bug to
call this function with an out-of-range value, in which case the function
will delay for at least the maximum value in the range and warns once.
The behavior above differs from the C side udelay() for which out-of-range
values could lead to an overflow and unexpected behavior.