Delta

Struct Delta 

pub struct Delta<U: TimeUnit = Nsec> { /* private fields */ }
A span of time.

The span is stored in the unit given by the type parameter U (see TimeUnit); its value has type U::Repr. U defaults to Nsec, so a plain Delta is a span in nanoseconds. The value can be negative, zero, or positive.

Implementations

Source

impl Delta<Jiffy>

pub const fn from_jiffies(jiffies: isize) -> Self

Create a new Delta from a number of jiffies.

pub const fn as_jiffies(self) -> isize

Return the number of jiffies in the Delta.

Source

impl Delta

pub const ZERO: Self

A span of time equal to zero.

pub const fn from_nanos(nanos: i64) -> Self

Create a new Delta from a number of nanoseconds.

pub const fn from_micros(micros: i64) -> Self

Create a new Delta from a number of microseconds.

The micros can range from -9_223_372_036_854_775 to 9_223_372_036_854_775. If micros is outside this range, i64::MIN is used for negative values, and i64::MAX is used for positive values due to saturation.

pub const fn from_millis(millis: i64) -> Self

Create a new Delta from a number of milliseconds.

The millis can range from -9_223_372_036_854 to 9_223_372_036_854. If millis is outside this range, i64::MIN is used for negative values, and i64::MAX is used for positive values due to saturation.

pub const fn from_secs(secs: i64) -> Self

Create a new Delta from a number of seconds.

The secs can range from -9_223_372_036 to 9_223_372_036. If secs is outside this range, i64::MIN is used for negative values, and i64::MAX is used for positive values due to saturation.

pub fn is_zero(self) -> bool

Return true if the Delta spans no time.

pub fn is_negative(self) -> bool

Return true if the Delta spans a negative amount of time.

pub const fn as_nanos(self) -> i64

Return the number of nanoseconds in the Delta.

pub fn as_micros_ceil(self) -> i64

Return the smallest number of microseconds greater than or equal to the value in the Delta.

pub fn as_millis(self) -> i64

Return the number of milliseconds in the Delta.

pub fn as_millis_ceil(self) -> i64

Return the smallest number of milliseconds greater than or equal to the value in the Delta.

pub fn rem_nanos(self, dividend: i32) -> Self

Return self % dividend where dividend is in nanoseconds.

The kernel doesn’t have any emulation for s64 % s64 on 32 bit platforms, so this is limited to 32 bit dividends.