pub enum AllocKind {
Alloc,
Alloc1,
}Expand description
Flags passed to XArray::new to configure the array’s allocation tracking behavior.
Variants
Alloc
Consider the first element to be at index 0.
Alloc1
Consider the first element to be at index 1.