pub const fn _mm256_cvtepu32_ps(a: __m256i) -> __m256🔬This is a nightly-only experimental API. (
stdarch_x86_avx512_vl_u32_to_f32_conversions #161585)Available on x86-64 and target feature
avx512f and target feature avx512vl and (x86 or x86-64) only.Expand description
Convert packed unsigned 32-bit integers in a to packed single-precision (32-bit) floating-point elements, and store the results in dst.
Due to an omission by Intel, these intrinsics are not documented in the Intrinsics Guide. Documentation on them can be found in the Intel Software Development Manual.