pub struct Device<Ctx: DeviceContext = Normal>(/* private fields */);Expand description
The auxiliary device representation.
This structure represents the Rust abstraction for a C struct auxiliary_device. The
implementation abstracts the usage of an already existing C struct auxiliary_device within
Rust code that we get passed from the C side.
Invariants
A Device instance represents a valid struct auxiliary_device created by the C portion of
the kernel.
Implementations
Sourceimpl<Ctx: DeviceContext> Device<Ctx>
impl<Ctx: DeviceContext> Device<Ctx>
Sourceimpl Device<Bound>
impl Device<Bound>
Sourcepub fn parent(&self) -> &Device<Bound>
pub fn parent(&self) -> &Device<Bound>
Returns a bound reference to the parent device::Device.
Sourcepub fn registration_data<F: ForLt + 'static>(&self) -> Result<Pin<&F::Of<'_>>>
pub fn registration_data<F: ForLt + 'static>(&self) -> Result<Pin<&F::Of<'_>>>
Returns a pinned reference to the registration data set by the registering (parent) driver.
F is the ForLt encoding of the data type. The returned
reference has its lifetime shortened from 'static to &self’s borrow lifetime via
ForLt::cast_ref.
Returns EINVAL if F does not match the type used by the parent driver when calling
Registration::new().
Returns ENOENT if no registration data has been set, e.g. when the device was
registered by a C driver.