pub struct Core<'a>(/* private fields */);Expand description
The Core context is the context of a bus specific device when it appears as argument of
any bus specific callback, such as probe().
The core context indicates that the Device<Core> reference’s scope is limited to the bus
callback it appears in. It is intended to be used for synchronization purposes. Bus device
implementations can implement methods for Device<Core>, such that they can only be called
from bus callbacks.