Device

Struct Device 

pub struct Device<T: Driver, C: DeviceContext = Registered> { /* private fields */ }
A typed DRM device with a specific drm::Driver implementation and DeviceContext.

Since DRM devices can be used before being fully initialized and registered with userspace, C represents the furthest DeviceContext we can guarantee that this Device has reached.

Keep in mind: this means that an unregistered device can still have the registration state Registered as long as it was registered with userspace once in the past, and that the behavior of such a device is still well-defined. Additionally, a device with the registration state Uninit simply does not have a guaranteed registration state at compile time, and could be either registered or unregistered. Since there is no way to guarantee a long-lived reference to an unregistered device would remain unregistered, we do not provide a DeviceContext for this.

Invariants

  • self.dev is a valid instance of a struct device.
  • The data layout of Self remains the same across all implementations of C.
  • Any invariants for C also apply.