pub struct Ioctl;Expand description
The DeviceContext of a Device that has been registered with userspace previously.
A Device in this context has been registered at some point, but may be concurrently
unregistering or already unregistered. drm_dev_enter() can guard against this, ensuring the
device remains registered for the duration of the critical section.
Invariants
A Device in this context has been registered with userspace via drm_dev_register() at
some point.