pub struct Normal;Expand description
The general-purpose, reference-counted DeviceContext.
A Device in this context may or may not be registered with userspace. This context is used
for reference-counted device handles and during device setup via UnregisteredDevice.
AlwaysRefCounted is only implemented for Device<T, Normal>, making this the required
context for ARef-based device handles.