pub struct Registered;Expand description
The DeviceContext of a Device that is currently registered with userspace.
A Device in this context is guaranteed to be registered and its parent bus device is
guaranteed to be bound. This is enforced at runtime by RegistrationGuard, which holds a
drm_dev_enter() / drm_dev_exit() SRCU critical section.
Invariants
The parent bus device is bound for the duration of any reference to a Device<T, Registered>.