pub struct Registered;Expand description
The DeviceContext of a Device that was registered with userspace at some point.
This represents a Device which is guaranteed to have been registered with userspace at
some point in time. Such a DRM device is guaranteed to have been fully-initialized.
Note: A device in this context is not guaranteed to remain registered with userspace for its entire lifetime, as this is impossible to guarantee at compile-time.
Invariants
A Device in this DeviceContext is guaranteed to have been registered with userspace
at some point in time.