pub struct RegistrationGuard<'a, T: Driver> { /* private fields */ }Expand description
A guard proving the DRM device is registered and the parent bus device is bound.
The guard dereferences to Device<T, Registered>, providing access to the DRM device with
the guarantee that the parent bus device is bound for the entire duration of the critical
section.
Internally this is backed by a drm_dev_enter() / drm_dev_exit() SRCU critical section.
Invariants
idxis the SRCU read lock index returned by a successfuldrm_dev_enter()call.- The parent bus device of
devis bound for the lifetime of this guard.
Methods from Deref<Target = Device<T, Registered>>
Sourcepub fn registration_data_with<R, F>(&self, f: F) -> Rwhere
F: for<'a> FnOnce(&'a T::RegistrationData<'a>) -> R,
pub fn registration_data_with<R, F>(&self, f: F) -> Rwhere
F: for<'a> FnOnce(&'a T::RegistrationData<'a>) -> R,
Access the registration data through a closure, with the lifetime tied to the closure scope.
The data is owned by Registration and is guaranteed to remain valid
as long as the device is registered, since Registration’s drop
calls drm_dev_unplug() which waits for all drm_dev_enter() critical sections to
complete.