pub struct Uninit;Expand description
The DeviceContext of a Device that may be unregistered and partly uninitialized.
A Device in this context is only guaranteed to be partly initialized, and may or may not
be registered with userspace. Thus operations which depend on the Device being fully
initialized, or which depend on the Device being registered with userspace are not
available through this DeviceContext.
A Device in this context can be used to create a
Registration.