pub struct Registration<'a, T: Driver> { /* private fields */ }Expand description
The registration type of a drm::Device.
Once the Registration structure is dropped, the device is unregistered.
Implementations
Sourceimpl<'a, T: Driver> Registration<'a, T>
impl<'a, T: Driver> Registration<'a, T>
Sourcepub unsafe fn new<E>(
dev: &'a Device<Bound>,
drm: UnregisteredDevice<T>,
reg_data: impl PinInit<T::RegistrationData<'a>, E>,
flags: usize,
) -> Result<Self>
pub unsafe fn new<E>( dev: &'a Device<Bound>, drm: UnregisteredDevice<T>, reg_data: impl PinInit<T::RegistrationData<'a>, E>, flags: usize, ) -> Result<Self>
Register a new UnregisteredDevice with userspace.
Safety
The caller must not mem::forget() the returned Registration or otherwise prevent its
Drop implementation from running, since the registration data may contain borrowed
references that become invalid after 'a ends.