pub struct VMap<D, R, const SIZE: usize = 0>{ /* private fields */ }Expand description
A reference to a virtual mapping for an shmem-based GEM object in kernel address space.
Invariants
- The size of
owneris >= SIZE. - The memory pointed to by
addrremains valid at least until this object is dropped.
Implementations