GpuBuddyAllocFlags

Struct GpuBuddyAllocFlags 

pub struct GpuBuddyAllocFlags(/* private fields */);
Modifier flags for GPU buddy allocation.

These flags can be combined with any GpuBuddyAllocMode to control additional allocation behavior.

Implementations

Source

impl GpuBuddyAllocFlags

pub const fn empty() -> Self

Returns an empty instance where no flags are set.

pub const fn all_bits() -> usize

Returns a mask containing all valid flag bits.

pub fn contains(self, flag: GpuBuddyAllocFlag) -> bool

Checks if a specific flag is set.

pub fn contains_any(self, flags: GpuBuddyAllocFlags) -> bool

Checks if at least one of the provided flags is set.

pub fn contains_all(self, flags: GpuBuddyAllocFlags) -> bool

Checks if all of the provided flags are set.