pub struct GpuBuddyAllocFlags(/* private fields */);Expand description
Modifier flags for GPU buddy allocation.
These flags can be combined with any GpuBuddyAllocMode to control
additional allocation behavior.
Implementations
Sourceimpl GpuBuddyAllocFlags
impl GpuBuddyAllocFlags
Sourcepub fn contains(self, flag: GpuBuddyAllocFlag) -> bool
pub fn contains(self, flag: GpuBuddyAllocFlag) -> bool
Checks if a specific flag is set.
Sourcepub fn contains_any(self, flags: GpuBuddyAllocFlags) -> bool
pub fn contains_any(self, flags: GpuBuddyAllocFlags) -> bool
Checks if at least one of the provided flags is set.
Sourcepub fn contains_all(self, flags: GpuBuddyAllocFlags) -> bool
pub fn contains_all(self, flags: GpuBuddyAllocFlags) -> bool
Checks if all of the provided flags are set.