pub struct CList<T, const OFFSET: usize>(/* private fields */);Expand description
A typed C linked list with a sentinel head intended for FFI use-cases where a C subsystem manages a linked list that Rust code needs to read. Generally required only for special cases.
A sentinel head CListHead represents the entire linked list and can be used
for iteration over items of type T; it is not associated with a specific item.
The const generic OFFSET specifies the byte offset of the list_head field within
the struct that T wraps.
Invariants
- The sentinel
CListHeadhas valid non-NULLnext/prevpointers. OFFSETis the byte offset of thelist_headfield within the struct thatTwraps.- All the list’s
list_headnodes have valid non-NULLnext/prevpointers.
Implementations
Sourceimpl<T, const OFFSET: usize> CList<T, OFFSET>
impl<T, const OFFSET: usize> CList<T, OFFSET>
Sourcepub unsafe fn from_raw<'a>(ptr: *mut list_head) -> &'a Self
pub unsafe fn from_raw<'a>(ptr: *mut list_head) -> &'a Self
Create a typed CList reference from a raw sentinel list_head pointer.
Safety
ptrmust be a valid pointer to an initialized sentinellist_head(e.g. viaINIT_LIST_HEAD()), with valid non-NULLnext/prevpointers.ptrmust remain valid for the lifetime'a.- The list and all linked nodes must not be concurrently modified for the lifetime
'a. - The list must contain items where the
list_headfield is at byte offsetOFFSET. Tmust be#[repr(transparent)]over the C struct.