CListHead

Struct CListHead 

pub struct CListHead { /* private fields */ }
FFI wrapper for a C list_head object used in intrusive linked lists.

Invariants

  • The underlying list_head is initialized with valid non-NULL next/prev pointers.

Implementations

Source

impl CListHead

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> CListHeadProjection<'__pin>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • inner

These fields are not structurally pinned:

Source

impl CListHead

pub unsafe fn from_raw<'a>(ptr: *mut list_head) -> &'a Self

Create a &CListHead reference from a raw list_head pointer.

Safety
  • ptr must be a valid pointer to an initialized list_head (e.g. via INIT_LIST_HEAD()), with valid non-NULL next/prev pointers.
  • ptr must remain valid for the lifetime 'a.
  • The list and all linked list_head nodes must not be modified from anywhere for the lifetime 'a, unless done so via any CListHead APIs.
pub fn as_raw(&self) -> *mut list_head

Get the raw list_head pointer.

pub fn next(&self) -> &Self

Get the next CListHead in the list.

pub fn is_linked(&self) -> bool

Check if this node is linked in a list (not isolated).

pub fn new() -> impl PinInit<Self>

Returns a pin-initializer for the list head.