pub struct IoMem<'a, const SIZE: usize = 0> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a, const SIZE: usize> IoMem<'a, SIZE>
impl<'a, const SIZE: usize> IoMem<'a, SIZE>
Sourcepub fn into_devres(self) -> Result<DevresIoMem<SIZE>>
pub fn into_devres(self) -> Result<DevresIoMem<SIZE>>
Consume the IoMem and register it as a device-managed resource.
The returned DevresIoMem can outlive the original borrow and be stored in driver data.
Access to the I/O memory is revoked automatically when the device is unbound.