IoMem

Struct IoMem 

pub struct IoMem<const SIZE: usize = 0> { /* private fields */ }
A generic memory-mapped IO region.

Accesses to the underlying region is checked either at compile time, if the region’s size is known at that point, or at runtime otherwise.

Invariants

IoMem always holds an MmioRaw instance that holds a valid pointer to the start of the I/O memory mapped region.

Implementations

Source

impl<const SIZE: usize> IoMem<SIZE>

pub fn new<'a>( io_request: IoRequest<'a>, ) -> impl PinInit<Devres<Self>, Error> + 'a

Creates a new IoMem instance from a previously acquired IoRequest.

Methods from Deref<Target = Mmio<SIZE>>

pub fn relaxed(&self) -> &RelaxedMmio<SIZE>

Returns a RelaxedMmio reference that performs relaxed I/O operations.

Relaxed accessors do not provide ordering guarantees with respect to DMA or memory accesses and can be used when such ordering is not required.

Examples
use kernel::io::{
    Io,
    Mmio,
    RelaxedMmio,
};

fn do_io(io: &Mmio<0x100>) {
    // The access is performed using `readl_relaxed` instead of `readl`.
    let v = io.relaxed().read32(0x10);
}