pub struct RelativeRegisterLoc<T: WithBase, B: ?Sized>(/* private fields */);Expand description
Location of a relative register.
This can either be an immediately accessible regular RelativeRegister, or a
RelativeRegisterArray that needs one additional resolution through
RelativeRegisterLoc::at.
Implementations
Sourceimpl<T, B> RelativeRegisterLoc<T, B>
impl<T, B> RelativeRegisterLoc<T, B>
Sourceimpl<T, B> RelativeRegisterLoc<T, B>
Methods exclusive to RelativeRegisterLocs created with a RelativeRegisterArray.
impl<T, B> RelativeRegisterLoc<T, B>
Methods exclusive to RelativeRegisterLocs created with a RelativeRegisterArray.
Sourcepub fn at(self, idx: usize) -> RelativeRegisterArrayLoc<T, B>
pub fn at(self, idx: usize) -> RelativeRegisterArrayLoc<T, B>
Returns the location of the register at position idx, with build-time validation.
Sourcepub fn try_at(self, idx: usize) -> Option<RelativeRegisterArrayLoc<T, B>>
pub fn try_at(self, idx: usize) -> Option<RelativeRegisterArrayLoc<T, B>>
Returns the location of the register at position idx, with runtime validation.