pub trait Array {
// Provided methods
fn at(idx: usize) -> RegisterArrayLoc<Self>
where Self: RegisterArray { ... }
fn try_at(idx: usize) -> Option<RegisterArrayLoc<Self>>
where Self: RegisterArray { ... }
}Expand description
Trait providing location builders for RegisterArrays.
Provided Methods
Sourcefn at(idx: usize) -> RegisterArrayLoc<Self>where
Self: RegisterArray,
fn at(idx: usize) -> RegisterArrayLoc<Self>where
Self: RegisterArray,
Returns the location of the register at position idx, with build-time validation.
Sourcefn try_at(idx: usize) -> Option<RegisterArrayLoc<Self>>where
Self: RegisterArray,
fn try_at(idx: usize) -> Option<RegisterArrayLoc<Self>>where
Self: RegisterArray,
Returns the location of the register at position idx, with runtime validation.