pub trait RegisterBase<T> {
const BASE: usize;
}Expand description
Trait providing a base address to be added to the offset of a relative register to obtain its actual offset.
The T generic argument is used to distinguish which base to use, in case a type provides
several bases. It is given to the register! macro to restrict the use of the register to
implementors of this particular variant.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.