pub trait WithBase {
type BaseFamily;
// Provided method
fn of<B: RegisterBase<Self::BaseFamily>>() -> RelativeRegisterLoc<Self, B>
where Self: Register { ... }
}Expand description
Trait implemented by all registers that are relative to a base.
Required Associated Types
Sourcetype BaseFamily
type BaseFamily
Family of bases applicable to this register.
Provided Methods
Sourcefn of<B: RegisterBase<Self::BaseFamily>>() -> RelativeRegisterLoc<Self, B>where
Self: Register,
fn of<B: RegisterBase<Self::BaseFamily>>() -> RelativeRegisterLoc<Self, B>where
Self: Register,
Returns the absolute location of this type when using B as its base.