pub struct MmioRaw<T: ?Sized> { /* private fields */ }Expand description
Raw representation of an MMIO region.
MmioRaw<T> is equivalent to T __iomem * in C.
By itself, the existence of an instance of this structure does not provide any guarantees that the represented MMIO region does exist or is properly mapped.
Instead, the bus specific MMIO implementation must convert this raw representation into an
Mmio instance providing the actual memory accessors. Only by the conversion into an Mmio
structure any guarantees are given.
Implementations