pub struct Region<const SIZE: usize = 0> { /* private fields */ }Expand description
Untyped I/O region.
This type can be used when an I/O region without known type information has a compile-time known minimum size (and a runtime known actual size).
Invariants
- Size of the region is at least as large as the
SIZEgeneric parameter. - Size of the region is multiple of 4.
Implementations
Sourceimpl<const SIZE: usize> Region<SIZE>
impl<const SIZE: usize> Region<SIZE>
Sourcepub fn ptr_from_raw_parts_mut(base: *mut u8, size: usize) -> *mut Self
pub fn ptr_from_raw_parts_mut(base: *mut u8, size: usize) -> *mut Self
Create a raw mutable pointer from given base address and size.
size should be at least as large as the minimum size SIZE, and base and size should
be 4-byte aligned to uphold the type invariant.
Just like other methods on raw pointers, it is not unsafe to create a raw pointer that does not uphold the type invariants. However such pointers are not valid.