pub struct Registration { /* private fields */ }Expand description
A registration of a generic netlink family.
This type represents the registration of a Family. When an instance of this type is
dropped, its respective generic netlink family will be unregistered from the system.
Invariants
self.family always holds a valid reference to an initialized and registered Family.