pub const fn u64_into_u32<const N: u64>() -> u32Expand description
Performs a build-time safe conversion of a u64 constant value into a u32.
This checks at compile-time that the conversion is lossless, and triggers a build error if it isn’t.
Examples
use kernel::num::casts;
// Succeeds because the value of the source fits into the destination's type.
assert_eq!(casts::u64_into_u32::<1u64>(), 1u32);