Bar

Struct Bar 

pub struct Bar<const SIZE: usize = 0> { /* private fields */ }
A PCI BAR to perform I/O-Operations on.

I/O backend assumes that the device is little-endian and will automatically convert from little-endian to CPU endianness.

Invariants

Bar always holds an IoRaw instance that holds a valid pointer to the start of the I/O memory mapped PCI BAR and its size.

Methods from Deref<Target = Mmio<SIZE>>

pub fn relaxed(&self) -> &RelaxedMmio<SIZE>

Returns a RelaxedMmio reference that performs relaxed I/O operations.

Relaxed accessors do not provide ordering guarantees with respect to DMA or memory accesses and can be used when such ordering is not required.

Examples
use kernel::io::{
    Io,
    Mmio,
    RelaxedMmio,
};

fn do_io(io: &Mmio<0x100>) {
    // The access is performed using `readl_relaxed` instead of `readl`.
    let v = io.relaxed().read32(0x10);
}