pub struct NullTerminatedFormatter<'a> { /* private fields */ }Expand description
A mutable reference to a byte buffer where a string can be written into.
The buffer will be automatically null terminated after the last written character.
Invariants
- The first byte of
bufferis always zero. - The length of
bufferis at least 1.
Implementations
Sourceimpl<'a> NullTerminatedFormatter<'a>
impl<'a> NullTerminatedFormatter<'a>